@@ -2,8 +2,9 @@ use log::*;
 use wolf_engine::*;
 
 pub fn main() {
-    // Wolf Engine includes a default logger for convenience, but using it is optional.
-    // Feel free to bring your own logger.
+    // If the "logging" feature is enabled, Wolf Engine includes a default logger for
+    // convenience, but using it is optional.  Feel free to bring your own logger instead.
+    #[cfg(feature = "logging")]
     initialize_logging(LevelFilter::Debug);
 
     // Initialize your game state.
