@@ -79,7 +79,12 @@ impl StateStack {
         Self { stack: vec![] }
     }
 
-    /// Indicates if there are any [State]s on the stack.
+    /// Is true if there are any [State]s on the stack.
+    pub fn is_not_empty(&self) -> bool {
+        !self.is_empty()
+    }
+
+    /// Is true if there are no [State]s on the stack.
     pub fn is_empty(&self) -> bool {
         self.stack.is_empty()
     }
@@ -120,6 +125,7 @@ impl StateStack {
         self.push(state);
     }
 
+    /// Pop all states off the stack.
     pub fn clear(&mut self) {
         while !self.is_empty() {
             self.pop();
